@@ -252,14 +252,16 @@ class SSHFS(FS):
 
         return self.opendir(path)
 
-    def move(self, src_path, dst_path, overwrite=False):
+    def move(self, src_path, dst_path, overwrite=False, preserve_time=False):
+        info_ns = ("basic", "details") if preserve_time else ("basic",)
+
         self.check()
         _src_path = self.validatepath(src_path)
         _dst_path = self.validatepath(dst_path)
 
         with self._lock:
             # check src exists and is a file
-            src_info = self.getinfo(_src_path)
+            src_info = self.getinfo(_src_path, namespaces=info_ns)
             if src_info.is_dir:
                 raise errors.FileExpected(src_path)
             # check dst is not a dir and can be created
@@ -271,10 +273,17 @@ class SSHFS(FS):
             if self.isfile(_dst_path):
                 if not overwrite:
                     raise errors.DestinationExists(dst_path)
-                with convert_sshfs_errors('remove', dst_path):
+                with convert_sshfs_errors('move', dst_path):
                     self._sftp.remove(_dst_path)
             # rename the file through SFTP's 'RENAME'
             self._sftp.rename(_src_path, _dst_path)
+            # preserve times if required
+            if preserve_time:
+                self._utime(
+                    _path,
+                    src_info.raw["details"]["modified"],
+                    src_info.raw["details"]["accessed"],
+                )
 
     def openbin(self, path, mode='r', buffering=-1, **options):  # noqa: D102
         """Open a binary file-like object.
@@ -421,8 +430,7 @@ class SSHFS(FS):
         """Set a file to the contents of a binary file object.
 
         This method uses the underlying `paramiko.SFTP.putfo` method, which
-        should be more efficient than manually opening and reading from a
-        file.
+        should be more efficient than manually opening and writing to a file.
 
         Arguments:
             path (str): A path on the filesystem.
@@ -587,8 +595,8 @@ class SSHFS(FS):
         """Set the *accessed* and *modified* times of a resource.
         """
         if accessed is not None or modified is not None:
-            accessed = int(modified if accessed is None else accessed)
-            modified = int(accessed if modified is None else modified)
+            accessed = float(modified if accessed is None else accessed)
+            modified = float(accessed if modified is None else modified)
             self._sftp.utime(path, (accessed, modified))
         else:
             self._sftp.utime(path, None)
